@@ -32,11 +32,11 @@ create_job = '''
   }
 '''
 
-update_job='''
+update_job = '''
   mutation UpdateJob(
     $id: ID!
     $status: JobStatus!
-    $output: Json
+    $output: Jsonb
     $progress: Int
   ) {
     updateJob(
@@ -58,7 +58,7 @@ update_job='''
   }
 '''
 
-delete_job='''
+delete_job = '''
   mutation abortJob($id: ID!) {
     updateJob(id: $id job: { jobStatus: ABORTED }) {
       successful
@@ -73,7 +73,7 @@ delete_job='''
   }
 '''
 
-upsert_queue='''
+upsert_queue = '''
 mutation upsertQueue(
   $name: String!
   $alias: String!
@@ -357,7 +357,7 @@ mutation UpdateLock($id: ID!, $active: Boolean!, $endAt: DateTime) {
 update_context = '''
 mutation UpdateContext(
   $queue: String!
-  $context: Json!
+  $context: Jsonb!
 ){
   updateQueue(
     findBy:{ name: $queue }
@@ -419,15 +419,16 @@ update_queue_worker = '''
   }
 '''
 
+
 def build_batch_stale_mutation(jobs):
-  batch_template = '''mutation DeleteStaleJobs{{\n\t{mutation_items}\n}}'''
-  item_template = '''{label}: updateJob(id: {id} job: {{ jobStatus: ABORTED }}) {{ successful messages{{field message}} }}'''
-  mutation_items = [
-    item_template.format(label= f'delete_job_{job["id"]}', id=job["id"])
-    for job in jobs
-  ]
-  return (
-    batch_template.format(mutation_items='\n\t'.join(mutation_items))
-      if jobs
-      else None
-  )
+    batch_template = '''mutation DeleteStaleJobs{{\n\t{mutation_items}\n}}'''
+    item_template = '''{label}: updateJob(id: {id} job: {{ jobStatus: ABORTED }}) {{ successful messages{{field message}} }}'''
+    mutation_items = [
+        item_template.format(label=f'delete_job_{job["id"]}', id=job["id"])
+        for job in jobs
+    ]
+    return (
+        batch_template.format(mutation_items='\n\t'.join(mutation_items))
+        if jobs
+        else None
+    )
