@@ -832,8 +832,10 @@ class ValiotWorker():
                 else:
                     _log(LogLevel.ERROR,
                          f'error unlocking {job_lock["job"]["queue"]["name"]}')
-        for u in unlocked:
-            self.lockedJobs.pop(u)
+        if unlocked:
+            unlocked.reverse()
+            for u in unlocked:
+                self.lockedJobs.pop(u)
 
     def runTimedOutEvents(self):
         """This function checks all queue that are in time out.
